===================
ECS Compose-X Specs
===================

`Specifications for ECS Compose-X.`_

Visit the `Compose-X repositories on GitHub`_, `use-cases walkthroughs`_ and the `blog`_

.. _Specifications for ECS Compose-X.: https://ecs-composex-specs.compose-x.io
.. _Compose-X repositories on GitHub: https://github.com/compose-x
.. _use-cases walkthroughs: https://labs.compose-x.io
.. _blog: https://blog.compose-x.io
